<?php
/**
 * The template for displaying meta box in page/post
 *
 * This adds Layout Options, Select Sidebar, Header Freatured Image Options, Single Page/Post Image Layout
 * This is only for the design purpose and not used to save any content
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

/**
 * Class to Add, Render and save metabox options
 *
 * @since Parallax Frame 1.0
 */
class parallax_frame_meta_box {
	private $meta_box;

	private $fields;

	/**
	* Constructor
	*
	* @since Parallax Frame 1.0
	*
	* @access public
	*
	*/
	public function __construct( $meta_box_id, $meta_box_title, $post_type ) {

		$this->meta_box = array (
			'id'        => $meta_box_id,
			'title'     => $meta_box_title,
			'post_type' => $post_type,
		);

		$this->fields = array(
			'parallax-frame-layout-option',
			'parallax-frame-header-image',
			'parallax-frame-sidebar-options',
			'parallax-frame-featured-image',
		);


		// Add metaboxes
		add_action( 'add_meta_boxes', array( $this, 'add' ) );

		add_action( 'save_post', array( $this, 'save' ) );
   	}

	/**
	* Add Meta Box for multiple post types.
	*
	* @since parallaxframe 1.
	*
	* @access public
	*/
	public function add( $post_type ) {
		add_meta_box( $this->meta_box['id'], $this->meta_box['title'], array( $this, 'show' ), $post_type, 'side', 'high' );
	}

	/**
	* Renders metabox
	*
	* @since Parallax Frame 1.0
	*
	* @access public
	*/
	public function show() {
		global $post;

		$layout_options			= parallax_frame_metabox_layouts();
		$sidebar_options		= parallax_frame_metabox_sidebar_options();
		$featured_image_options	= parallax_frame_metabox_featured_image_options();
		$header_image_options 	= parallax_frame_metabox_header_featured_image_options();


	    // Use nonce for verification
	    wp_nonce_field( basename( __FILE__ ), 'parallax_frame_custom_meta_box_nonce' );

	    // Begin the field table and loop  ?>
	    <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-layout-option"><?php esc_html_e( 'Layout Options', 'parallax-frame-pro' ); ?></label></p>
            <select name="parallax-frame-layout-option" id="custom_element_grid_class">
					<?php
					$metalayout = get_post_meta( $post->ID, 'parallax-frame-layout-option', true );

                if ( empty( $metalayout ) ){
                    $metalayout = 'default';
                }

                foreach ( $layout_options as $field ) {
               	?>
               		<option value="<?php echo esc_attr( $field['value'] ); ?>" <?php selected( $metalayout, $field['value'] ); ?>><?php echo esc_html( $field['label'] ); ?></option>
				<?php
				} // end foreach
                ?>
            </select>
        	
        	<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-sidebar-options"><?php esc_html_e( 'Select Sidebar', 'parallax-frame-pro' ); ?></label></p>
			<select class="widefat" name="parallax-frame-sidebar-options" id="parallax-frame-sidebar-options">
            <?php
            $metasidebar = get_post_meta( $post->ID, 'parallax-frame-sidebar-options', true );

            if ( empty( $metasidebar ) ){
                $metasidebar = 'default-sidebar';
            }

            foreach ( $sidebar_options as $field ) {
            ?>
            	<option value="<?php echo esc_attr( $field['value'] ); ?>" <?php selected( $metasidebar, $field['value'] ); ?>><?php echo esc_html( $field['label'] ); ?></option>
            <?php
            } // end foreach
            ?>
       		</select>
            <?php
			 	$metaheader = get_post_meta( $post->ID, 'parallax-frame-header-image', true );

                if ( empty( $metaheader ) ){
                    $metaheader='default';
                }
				?>

                <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-sidebar-options"><?php esc_html_e( 'Header Image Option', 'parallax-frame-pro' ); ?></label></p>
                <select name="parallax-frame-header-image">
                    <?php foreach ( $header_image_options as $field ) { ?>
                    <option <?php selected( $field['value'], $metaheader ); ?> value="<?php echo $field['value'];?>"><?php echo $field['label']; ?></option>
                  	<?php }//end foreach ?>
                </select>

                <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-featured-header-title"><?php esc_html_e( 'Title', 'parallax-frame-pro' ); ?></label></p>
            
            	<?php
					$type  = 'text';
					$name  = 'parallax-frame-featured-header-title';
					$value = get_post_meta( $post->ID, $name, true );
    			?>

                <input  class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
        	
                <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-sidebar-options"><?php esc_html_e( 'Content', 'parallax-frame-pro' ); ?></label></p>
            
            	<?php
					$name  = 'parallax-frame-featured-header-content';
					$value = get_post_meta( $post->ID, $name, true );
    			?>

                <textarea class= "widefat" rows="4" name="<?php echo esc_attr( $name ); ?>"><?php echo esc_textarea( $value ); ?></textarea>
        	
                <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-sidebar-options"><?php esc_html_e( 'Button Text', 'parallax-frame-pro' ); ?></label></p>
            
            	<?php
					$type  = 'text';
					$name  = 'parallax-frame-featured-header-button-text';
					$value = get_post_meta( $post->ID, $name, true );
    			?>

                <input class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
        	
                <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="parallax-frame-sidebar-options"><?php esc_html_e( 'Button Link', 'parallax-frame-pro' ); ?></label></p>
           
            	<?php
					$type  = 'text';
					$name  = 'parallax-frame-featured-header-button-link';
					$value = get_post_meta( $post->ID, $name, true );
    			?>

                <input class= "widefat" type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" value="<?php echo esc_attr( $value ); ?>"/>
        	
        		<?php
					$type  = 'checkbox';
					$name  = 'parallax-frame-featured-header-button-target';
					$value = get_post_meta( $post->ID, $name, true );

				?>

                <div class="components-panel__row">
					<div class="components-base-control">
						<div class="components-base-control__field">
							<input type="<?php echo esc_attr( $type ); ?>" name="<?php echo esc_attr( $name ); ?>" id="parallax-frame-featured-header-button-target" value="1" <?php checked( $value, true ); ?>/><label class="components-checkbox-control__label" for="parallax-frame-featured-header-button-target"><?php esc_html_e( 'Open Link in New Tab', 'parallax-frame-pro' ); ?></label>
						</div>
					</div>
				</div>


            <p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="fullframe-header-image"><?php esc_html_e( 'Header Featured Image Options', 'parallax-frame-pro' ); ?></label></p>
             <select name="parallax-frame-featured-image" id="custom_element_grid_class">
                 <?php
             		$metaimage = get_post_meta( $post->ID, 'parallax-frame-featured-image', true );
                    if ( empty( $metaimage ) ){
                        $metaimage='default';
                    }

                	foreach ( $featured_image_options as $field ) {
               	?>
               		<option value="<?php echo $field['value']; ?>" <?php selected( $metaimage, $field['value'] ); ?>><?php echo $field['label']; ?></option>
				<?php
				} // end foreach
                ?>
            </select> 
	<?php
	}

	/**
	 * Save custom metabox data
	 *
	 * @action save_post
	 *
	 * @since Parallax Frame 1.0
	 *
	 * @access public
	 */
	public function save( $post_id ) {
		global $post_type;

		$post_type_object = get_post_type_object( $post_type );

	    if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
	    || ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
	    || ( ! in_array( $post_type, $this->meta_box['post_type'] ) )                  // Check if current post type is supported.
	    || ( ! check_admin_referer( basename( __FILE__ ), 'parallax_frame_custom_meta_box_nonce') )    // Check nonce - Security
	    || ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
	    {
	      return $post_id;
	    }

	    foreach ( $this->fields as $field ) {
			$new = $_POST[ $field ];

			if ( '' == $new || array() == $new ) {
				continue;
			}
			else {
				if ( ! update_post_meta ( $post_id, $field, sanitize_key ( $new ) ) ) {
					add_post_meta( $post_id, $field, sanitize_key ( $new ), true );
				}
			}
		} // end foreach

		//Validation for header image extra options
		$title = $_POST['parallax-frame-featured-header-title'];
		if ( '' != $title ) {
			if ( ! update_post_meta ( $post_id, 'parallax-frame-featured-header-title', wp_kses_post ( $title ) ) ) {
				add_post_meta( $post_id, 'parallax-frame-featured-header-title', wp_kses_post ( $title ), true );
			}
		}

		$content = $_POST['parallax-frame-featured-header-content'];
		if ( '' != $content ) {
			if ( ! update_post_meta ( $post_id, 'parallax-frame-featured-header-content', wp_kses_post ( $content ) ) ) {
				add_post_meta( $post_id, 'parallax-frame-featured-header-content', wp_kses_post ( $content ), true );
			}
		}

		$button_text = $_POST['parallax-frame-featured-header-button-text'];
		if ( '' != $button_text ) {
			if ( ! update_post_meta ( $post_id, 'parallax-frame-featured-header-button-text', sanitize_text_field ( $button_text ) ) ) {
				add_post_meta( $post_id, 'parallax-frame-featured-header-button-text', sanitize_text_field ( $button_text ), true );
			}
		}

		$button_link = $_POST['parallax-frame-featured-header-button-link'];
		if ( '' != $button_link ) {
			if ( ! update_post_meta ( $post_id, 'parallax-frame-featured-header-button-link', esc_url_raw( $button_link ) ) ) {
				add_post_meta( $post_id, 'parallax-frame-featured-header-button-link', esc_url_raw ( $button_link ), true );
			}
		}

		$button_target = isset( $_POST['parallax-frame-featured-header-button-target'] ) ? $_POST['parallax-frame-featured-header-button-target'] : '';
		delete_post_meta( $post_id, 'parallax-frame-featured-header-button-target' );
		if ( '' != $button_target ) {
			if ( ! update_post_meta ( $post_id, 'parallax-frame-featured-header-button-target', ( bool ) $button_target ) ) {
				add_post_meta( $post_id, 'parallax-frame-featured-header-button-target', ( bool ) $button_target, true );
			}
		}
	}
}

$parallax_frame_metabox = new parallax_frame_meta_box(
	'parallax-frame-options', 					//metabox id
	esc_html__( 'Parallax Frame Options', 'parallax-frame-pro' ), //metabox title
	array( 'page', 'post' )				//metabox post types
);
