<?php
/**
 * Advertisement Code Widget
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */


/**
 * Makes a custom Widget for Displaying Code Ads
 *
 * Learn more: http://codex.wordpress.org/Widgets_API#Developing_Widgets
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */
class parallax_frame_advertisement_code_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title'           => '',
			'items_number'    => 1,
			'layout'          => 'one-column',
			'enable_hide_404' => 1,
		);

		$widget_ops = array(
			'classname'   => 'ct-advertisement-code ctadvertisement',
			'description' => esc_html__( 'Use this widget to add Code as Advertisement', 'parallax-frame-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-advertisement-code',
		);

		parent::__construct(
			'ct-advertisement-code', // Base ID
			__( 'CT: Advertisement Codes', 'parallax-frame-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

	/**
	 * Creates the form for the widget in the back-end which includes the Title , adcode, code, alt
	 * $instance Current settings
	 */
	function form($instance) {
		//* Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
        <p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'parallax-frame-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Layout', 'parallax-frame-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column' => esc_html__( '1 Column', 'parallax-frame-pro' ),
						'two-column' => esc_html__( '2 Column', 'parallax-frame-pro' )
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'items_number' ); ?>"><?php esc_html_e( 'No. of Items', 'parallax-frame-pro' ); ?>:</label>
			<input type="number" id="<?php echo $this->get_field_id( 'items_number' ); ?>" name="<?php echo $this->get_field_name( 'items_number' ); ?>" value="<?php echo absint( $instance['items_number'] ); ?>" class="small-text" min="1" />
			<br>
			<span class="description"><?php esc_html_e( 'Please save the widget once No. of items is changed to reflect the changes', 'parallax-frame-pro' ); ?></span>
		</p>

		<?php for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) { ?>

		<?php
			$code =  isset( $instance['code' . '_' .  $i] ) ? $instance['code' . '_' .  $i] : '';
		?>

		<p>
        	<label for="<?php echo $this->get_field_id('code' . '_' .  $i ); ?>">
        		<?php printf( esc_html__( 'Code %1s', 'parallax-frame-pro' ), $i ); ?>
        	</label>

        	<textarea class="ct-textarea" name="<?php echo $this->get_field_name('code' . '_' .  $i ); ?>" id="<?php echo $this->get_field_id('code' . '_' .  $i ); ?>"><?php echo esc_textarea( $code ); ?></textarea>
        </p>
	    <?php } //end for ?>

	    <p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['enable_hide_404'], true ) ?> id="<?php echo $this->get_field_id('enable_hide_404'); ?>" name="<?php echo $this->get_field_name('enable_hide_404'); ?>" /> <label for="<?php echo $this->get_field_id('enable_hide_404'); ?>"><?php esc_html_e( 'Check to Hide Ad on 404 page', 'parallax-frame-pro' ); ?></label>
		</p>

        <?php
	}

	/**
	 * update the particular instant
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * $new_instance New settings for this instance as input by the user via form()
	 * $old_instance Old settings for this instance
	 * Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$instance 				= $old_instance;

		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['layout']          = sanitize_key( $new_instance['layout'] );
		$instance['items_number']    = absint( $new_instance['items_number'] );
		$instance['enable_hide_404'] = parallax_frame_sanitize_checkbox( $new_instance['enable_hide_404'] );

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$instance['code' . '_' .  $i]
				= wp_kses_stripslashes( $new_instance['code' . '_' .  $i] );
		}

		return $instance;
	}

	/**
	 * Displays the Widget in the front-end.
	 *
	 * $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		// Merge with defaults
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		if ( $instance['enable_hide_404'] && is_404() ) {
			//Bail Early if the page is 404 error page and the widget is set to be hidden in that page
			return;
		}

		echo $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}


		echo '<div class="ads-code-wrap ' . esc_attr( $instance['layout'] ) . '">';

		for( $i=1; $i<= absint( $instance['items_number'] ); $i++ ) {
			$code =  isset( $instance['code' . '_' .  $i] ) ? $instance['code' . '_' .  $i] : '';

			if ( '' != $code ) {
				echo '<div class="ads-code ads-hentry hentry">';

				echo do_shortcode( $code );

				echo '</div><!-- .ads-code -->';
			}
		}

		echo '</div><!-- .ads-code-wrap -->';

		echo $args['after_widget'];
	}

}

/**
 * Initialize Widget
 */
function parallax_frame_advertisement_code_init() {
	register_widget( 'parallax_frame_advertisement_code_widget' );
}
add_action( 'widgets_init', 'parallax_frame_advertisement_code_init' );


